Computes the standard error of Cohen's d using only the two sample sizes and an estimate of Cohen's d. Cohen's d and its standard error assume equal variances. The estimate of Cohen's d, with the standard error output from this function, can be used as input in the meta.ave.gen, meta.lc.gen, and meta.lm.gen functions in applications where different types of compatible standardized mean differences are used in the meta-analysis. If the means, standard deviations, and sample sizes for the two groups are available, use the se.stdmean2 function which does not assume equal variances. The standard error for Cohen's d can be very inaccurate if the variances are unequal and the sample sizes are unequal.
For more details, see Chapter 1 of Bonett (2021, Volume 5)